# prepaidcs-value-fetcher

## Installation
```shell
pip install prepaidcsValueFetcher
```

```shell
pip install git+https://github.com/xh-dev-py/prepaidcsValueFetcher
```


## Build
```shell
python setup.py sdist bdist_wheel
```